@@ -20,6 +20,7 @@
    Boston, MA 02110-1301, USA.
 */
 
+#include "config-keditbookmarks.h"
 #include "globalbookmarkmanager.h"
 #include "importers.h"
 #include "kbookmarkmodel/commandhistory.h"
@@ -38,7 +39,12 @@
 
 #include <KMessageBox>
 #include <KWindowSystem>
-
+#include <kwindowsystem_version.h>
+#if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5, 101, 0)
+#if HAVE_X11
+#include <KX11Extras>
+#endif
+#endif
 #include <KBookmarkManager>
 #include <QStandardPaths>
 #include <kbookmarkexporter.h>
@@ -89,7 +95,13 @@ static bool askUser(const QString &filename, bool &readonly)
                     if (value.isValid())
                         id = value;
                     ////qCDebug(KEDITBOOKMARKS_LOG)<<" id !!!!!!!!!!!!!!!!!!! :"<<id;
+#if KWINDOWSYSTEM_VERSION >= QT_VERSION_CHECK(5, 101, 0)
+#if HAVE_X11
+                    KX11Extras::activateWindow((WId)id);
+#endif
+#else
                     KWindowSystem::activateWindow((WId)id);
+#endif
                     return false;
 #if KWIDGETSADDONS_VERSION >= QT_VERSION_CHECK(5, 100, 0)
                 } else if (ret == KMessageBox::ButtonCode::PrimaryAction) {
@@ -126,7 +138,7 @@ int main(int argc, char **argv)
                          QStringLiteral(KEDITBOOKMARKS_VERSION_STRING),
                          i18n("Bookmark Organizer and Editor"),
                          KAboutLicense::GPL,
-                         i18n("Copyright 2000-2017, KDE developers"));
+                         i18n("Copyright 2000-2023, KDE developers"));
     aboutData.addAuthor(i18n("David Faure"), i18n("Initial author"), QStringLiteral("faure@kde.org"));
     aboutData.addAuthor(i18n("Alexander Kellett"), i18n("Author"), QStringLiteral("lypanov@kde.org"));
 
@@ -171,6 +183,11 @@ int main(int argc, char **argv)
     const bool browser = !parser.isSet(QStringLiteral("nobrowser"));
     const bool gotFilenameArg = (parser.positionalArguments().count() == 1);
 
+    if (!gotFilenameArg) {
+        const QString location = QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/konqueror/");
+        QDir().mkpath(location);
+    }
+
     QString filename = gotFilenameArg ? parser.positionalArguments().at(0)
                                       : QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + QLatin1String("/konqueror/bookmarks.xml");
 
